@@ -1,20 +1,20 @@
-( cd opt/kde/share/doc/HTML/fr/kchart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kchart ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kformula ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kformula ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kivio ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kivio ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kugar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kugar ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/koffice ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/koffice ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/koshell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/koshell ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kpresenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kpresenter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kspread ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kspread ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kugar ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kugar ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kword ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kword ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kchart ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kpresenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kpresenter ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kplato ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kplato ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/thesaurus ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kformula ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kformula ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
